@@ -94,7 +94,7 @@ class _Should(object):
 
     @property
     def _flag(self):
-        return '' if self._not else 'not '
+        return 'not ' if self._not else ''
 
     def _assert(self, res, msg):
         ''' 统一的 assert 方法, 每次断言之后取消取否 '''
